#!/bin/bash
# Displays track change Popups using libnotify, for a better integration
# in a Gnome desktop.
# Constantin Bergemann < cbergemann AT gmxpro DOT de >
# Released as Beerware

if [ ! `which kreadconfig` ]; then
	msg="kreadconfig not found, please install."
	dcop amarok playlist popupMessage "${msg}"
	exit 1
elif [ ! `which mogrify` ]; then
	msg="mogrify not found, please install ImageMagick."
	dcop amarok playlist popupMessage "${msg}"
	exit 1
elif [ ! `which notify-send` ]; then
	msg="notify-send not found, please install libnotify."
	dcop amarok playlist popupMessage "${msg}"
	exit 1
fi

duration="`kreadconfig --file amarokrc --group OSD --key 'Osd Duration'`"
notify="notify-send -u normal -t ${duration}"
cover_size="64x64"

summary="Amarok"

lng="`echo $LANG | cut -b -2`"
if [ $lng == "de" ]; then
	str_end="Wiedergabeliste zu Ende."
	no_conf="Dieses Script hat nichts zu konfigurieren."
else
	str_end="Playlist finished"
	no_conf="This script does not have configuration options."
fi

while read cmd arg; do
	if [ "x$cmd" == "xconfigure" ]; then
		dcop amarok playlist popupMessage "${no_conf}"
	elif [ "x$cmd" == "xtrackChange" ]; then
		trackinfo="`dcop amarok player artist` - `dcop amarok player title`
`dcop amarok player album`"
		tempfile="`mktemp`"
		coverimg="`dcop amarok player coverImage`"
		cp ${coverimg} ${tempfile}
		mogrify -sample ${cover_size} ${tempfile}
		${notify} -i "${tempfile}" "${summary}" "${trackinfo}"
		rm ${tempfile}
	elif [ "x$cmd" == "xengineStateChange" ]; then
		if [ "x$arg" == "xempty" ]; then
			${notify} -i amarok "${summary}" "${str_end}"
		elif [ "x$arg" == "xidle" ]; then
			${notify} -i amarok "${summary}" "idle"
		fi
	fi
done

